@@ -1,6 +1,6 @@
 from Acquisition import aq_inner
 
-from zope.component import getMultiAdapter
+from zope.component import getMultiAdapter, ComponentLookupError
 from zope.interface import implements
 
 from plone.portlets.interfaces import IPortletDataProvider
@@ -9,7 +9,7 @@ from plone.memoize.view import memoize
 
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
-from xm.portlets import ProjectPortletMessageFactory as _
+from xm.portlets import PortletsMessageFactory as _
 
 
 class IProjectPortlet(IPortletDataProvider):
@@ -93,12 +93,15 @@ class Renderer(base.Renderer):
             tracker = self.tracker_url()
             attachments = self.attachments_url()
             offers = self.offers_url()
+            chart = self.chart_url()
             if tracker:
                 results.append(dict(url=tracker, title=_(u'Issues')))
             if attachments:
                 results.append(dict(url=attachments, title=_(u'Attachments')))
             if offers:
                 results.append(dict(url=offers, title=_(u'Offer')))
+            if chart:
+                results.append(dict(url=chart, title=_(u'Overview Chart')))
         for res in results:
             row = (results.index(res)+1)%2 and 'odd' or 'even'
             res['class'] = 'portletItem ' + row
@@ -160,6 +163,18 @@ class Renderer(base.Renderer):
             return self.project_url + '/project_content?type=offer'
         return None
 
+    def chart_url(self):
+        """ Return the url to the chart overview, if it has data"""
+        try:
+            chart = getMultiAdapter((self.project, self.request),
+                                            name=u'chart')
+        except ComponentLookupError:
+            return None
+                
+        if chart.has_data():
+            return self.project_url + '/@@chart_view'
+        return None
+        
 
 class AddForm(base.NullAddForm):
     """Portlet add form.
